@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 our $SOURCE = 'CPAN';
 ## $SOURCE = 'GitHub';  # COMMENT
 # the line above will be commented out by Dist::Zilla
@@ -1105,17 +1105,17 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Packy Anderson Alexandr Alexey Ciornii Melezhik aggregatetimespent
-Atlassian GreenHopper JRC ScriptRunner TODO aggregateprogress
-aggregatetimeestimate aggregatetimeoriginalestimate assigneeType avatar
-avatarUrls completeDate displayName duedate emailAddress endDate fieldtype
-fixVersions fromString genericized iconUrl isAssigneeTypeValid issueTypes
-issuekeys issuelinks issuetype jira jql lastViewed maxResults
-originalEstimate originalEstimateSeconds parentkey projectId rapidViewId
-remainingEstimate remainingEstimateSeconds resolutiondate sprintlist
-startDate subtaskIssueTypes timeSpent timeSpentSeconds timeestimate
-timeoriginalestimate timespent timetracking toString updateAuthor worklog
-workratio
+=for :stopwords Packy Anderson Alexandr Alexey Ciornii Heumann Manni Melezhik
+aggregatetimespent Atlassian GreenHopper JRC ScriptRunner TODO
+aggregateprogress aggregatetimeestimate aggregatetimeoriginalestimate
+assigneeType avatar avatarUrls completeDate displayName duedate
+emailAddress endDate fieldtype fixVersions fromString genericized iconUrl
+isAssigneeTypeValid issueTypes issuekeys issuelinks issuetype jira jql
+lastViewed maxResults originalEstimate originalEstimateSeconds parentkey
+projectId rapidViewId remainingEstimate remainingEstimateSeconds
+resolutiondate sprintlist startDate subtaskIssueTypes timeSpent
+timeSpentSeconds timeestimate timeoriginalestimate timespent timetracking
+toString updateAuthor worklog workratio
 
 =head1 NAME
 
@@ -1123,7 +1123,7 @@ JIRA::REST::Class::Issue - A helper class for L<JIRA::REST::Class|JIRA::REST::Cl
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 DESCRIPTION
 
