@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 our $SOURCE = 'CPAN';
 ## $SOURCE = 'GitHub';  # COMMENT
 # the line above will be commented out by Dist::Zilla
@@ -105,7 +105,8 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Packy Anderson Alexandr Alexey Ciornii Melezhik iconUrl updateAuthor
+=for :stopwords Packy Anderson Alexandr Alexey Ciornii Heumann Manni Melezhik iconUrl
+updateAuthor
 
 =head1 NAME
 
@@ -113,7 +114,7 @@ JIRA::REST::Class::Issue::Comment - A helper class for L<JIRA::REST::Class|JIRA:
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 METHODS
 
