@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 our $SOURCE = 'CPAN';
 ## $SOURCE = 'GitHub';  # COMMENT
 # the line above will be commented out by Dist::Zilla
@@ -129,8 +129,8 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Packy Anderson Alexandr Alexey Ciornii Melezhik Atlassian GreenHopper JRC
-ScriptRunner TODO aggregateprogress aggregatetimeestimate
+=for :stopwords Packy Anderson Alexandr Alexey Ciornii Heumann Manni Melezhik Atlassian
+GreenHopper JRC ScriptRunner TODO aggregateprogress aggregatetimeestimate
 aggregatetimeoriginalestimate assigneeType avatar avatarUrls completeDate
 displayName duedate emailAddress endDate fieldtype fixVersions fromString
 genericized iconUrl isAssigneeTypeValid issueTypes issuekeys issuelinks
@@ -147,7 +147,7 @@ JIRA::REST::Class::Issue::TimeTracking - A helper class for L<JIRA::REST::Class|
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 METHODS
 
